| Title: | Improved Infrence for Multilevel Models with Few Clusters |
|---|---|
| Description: | Support for inference about linear mixed effects models estimated with 'lmer' from package 'lme4' using a Student's t-distribution with degrees of freedom determined by the m-l-1 heuristic or the Kenward-Roger method. |
| Authors: | Martin Elff [aut, cre] |
| Maintainer: | Martin Elff <[email protected]> |
| License: | GPL (>=3) |
| Version: | 0.1 |
| Built: | 2026-04-18 08:17:37 UTC |
| Source: | https://github.com/melff/iimm |
Function lmer_t provides confidence intervals and p-values
based on the m-l-1 heuristic, the Satterthwaite and Kenward-Roger methods for models fitted with lmer.
lmer_t(object, method = c("Heuristic", "Satterthwaite", "Kenward-Roger"), level = 0.95)lmer_t(object, method = c("Heuristic", "Satterthwaite", "Kenward-Roger"), level = 0.95)
object |
an object representing a linear mixed effects model, as returned by |
method |
a character string that selects the method used to determine the degrees of freedom. |
level |
a number between 0 and 1, the level of the confidence intervals |
The function returns a list with two elements "lmer" - the original
object - and "coefTab" which is a matrix with estimates, standard errors,
t-statistics, degrees of freedom, lower and upper confidence intervals, and p-values.